scopus
======

Access Elsevier Scopus's API from Python on a large scale.

Documentation: https://scopus.readthedocs.io

Development: https://github.com/scopus-api/scopus

.. image:: https://badge.fury.io/py/scopus.svg
    :target: https://badge.fury.io/py/scopus

.. image:: https://readthedocs.org/projects/scopus/badge/?version=latest
    :target: https://readthedocs.org/projects/scopus/badge/?version=latest

.. image:: https://img.shields.io/pypi/pyversions/scopus.svg
    :target: https://img.shields.io/pypi/pyversions/scopus.svg

.. image:: https://img.shields.io/pypi/l/scopus.svg
    :target: https://img.shields.io/pypi/l/scopus.svg

Installation
============

Install stable version from PyPI:

.. code:: bash

    pip install scopus

or development version from GitHub repository:

.. code:: bash

    pip install git+git://github.com/scopus-api/scopus

Change log
==========

Please see `CHANGES.rst <CHANGES.rst>`_.

Contributing
============

Please see `CONTRIBUTING.rst <CONTRIBUTING.rst>`_. For a list of contributors see
`AUTHORS.rst <AUTHORS.rst>`_.

License
=======

MIT License; see `LICENSE <LICENSE>`_.
